@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,7 @@
 #include "print/knoteprintobject.h"
 
 #include <Akonadi/Item>
-#include <Akonadi/Notes/NoteUtils>
+#include <Akonadi/NoteUtils>
 
 #include <KMime/Message>
 
@@ -19,9 +19,7 @@ KNotesGrantleePrintTest::KNotesGrantleePrintTest(QObject *parent)
 {
 }
 
-KNotesGrantleePrintTest::~KNotesGrantleePrintTest()
-{
-}
+KNotesGrantleePrintTest::~KNotesGrantleePrintTest() = default;
 
 void KNotesGrantleePrintTest::shouldReturnEmptyStringWhenNotContentAndNoNotes()
 {
